@@ -65,15 +65,20 @@ sql_data_copy <- function(value, conn, row.names = FALSE) {
 
   value <- fix_posixt(value, conn@timezone)
 
-  value[is_difftime] <- lapply(value[is_difftime], function(col) format_keep_na(hms::as_hms(col)))
+  value[is_difftime] <- lapply(value[is_difftime], function(col) {
+    format_keep_na(hms::as_hms(col))
+  })
   value[is_blob] <- lapply(
     value[is_blob],
     function(col) {
       vapply(
         col,
         function(x) {
-          if (is.null(x)) NA_character_
-          else paste0("\\x", paste(format(x), collapse = ""))
+          if (is.null(x)) {
+            NA_character_
+          } else {
+            paste0("\\x", paste(format(x), collapse = ""))
+          }
         },
         character(1)
       )
@@ -107,8 +112,11 @@ db_append_table <- function(conn, name, value, copy, warn) {
 
     fields <- dbQuoteIdentifier(conn, names(value))
     sql <- paste0(
-      "COPY ", dbQuoteIdentifier(conn, name),
-      " (", paste(fields, collapse = ", "), ")",
+      "COPY ",
+      dbQuoteIdentifier(conn, name),
+      " (",
+      paste(fields, collapse = ", "),
+      ")",
       " FROM STDIN"
     )
     connection_copy_data(conn@ptr, sql, value)
@@ -120,8 +128,12 @@ db_append_table <- function(conn, name, value, copy, warn) {
   nrow(value)
 }
 
-list_tables <- function(conn, where_schema = NULL, where_table = NULL, order_by = NULL) {
-
+list_tables <- function(
+  conn,
+  where_schema = NULL,
+  where_table = NULL,
+  order_by = NULL
+) {
   query <- paste0(
     # information_schema.table docs: https://www.postgresql.org/docs/current/infoschema-tables.html
     "SELECT table_schema, table_name \n",
@@ -140,9 +152,13 @@ list_tables <- function(conn, where_schema = NULL, where_table = NULL, order_by
     query <- paste0(query, "  AND ", where_schema)
   }
 
-  if (!is.null(where_table)) query <- paste0(query, "  AND ", where_table)
+  if (!is.null(where_table)) {
+    query <- paste0(query, "  AND ", where_table)
+  }
 
-  if (!is.null(order_by)) query <- paste0(query, "ORDER BY ", order_by)
+  if (!is.null(order_by)) {
+    query <- paste0(query, "ORDER BY ", order_by)
+  }
 
   query
 }
@@ -177,7 +193,8 @@ list_fields <- function(conn, id) {
     # either the user provides the schema
     query <- paste0(
       "(SELECT 1 AS nr, ",
-      dbQuoteString(conn, name[["schema"]]), "::varchar",
+      dbQuoteString(conn, name[["schema"]]),
+      "::varchar",
       " AS table_schema) t"
     )
 
@@ -222,9 +239,11 @@ list_fields <- function(conn, id) {
   # join columns info
   table <- dbQuoteString(conn, name[["table"]])
   query <- paste0(
-    query, " ",
+    query,
+    " ",
     "INNER JOIN INFORMATION_SCHEMA.COLUMNS USING (table_schema) ",
-    "WHERE table_name = ", table
+    "WHERE table_name = ",
+    table
   )
 
   if (only_first) {
@@ -232,14 +251,16 @@ list_fields <- function(conn, id) {
     # https://stackoverflow.com/a/31814584/946850
     query <- paste0(
       "(SELECT *, rank() OVER (ORDER BY nr) AS rnr ",
-      "FROM ", query,
+      "FROM ",
+      query,
       ") tttt WHERE rnr = 1"
     )
   }
 
   query <- paste0(
     "SELECT column_name FROM ",
-    query, " ",
+    query,
+    " ",
     "ORDER BY ordinal_position"
   )
 
@@ -253,8 +274,9 @@ list_fields <- function(conn, id) {
 }
 
 find_temp_schema <- function(conn, fail_if_missing = TRUE) {
-  if (!is.na(connection_get_temp_schema(conn@ptr)))
+  if (!is.na(connection_get_temp_schema(conn@ptr))) {
     return(connection_get_temp_schema(conn@ptr))
+  }
   if (is(conn, "RedshiftConnection")) {
     temp_schema <- dbGetQuery(
       conn,
@@ -270,7 +292,9 @@ find_temp_schema <- function(conn, fail_if_missing = TRUE) {
       return(connection_get_temp_schema(conn@ptr))
     } else {
       # Temporary schema do not exist yet.
-      if (fail_if_missing) stopc("temporary schema does not exist")
+      if (fail_if_missing) {
+        stopc("temporary schema does not exist")
+      }
       return(NULL)
     }
   } else {
