@@ -7,7 +7,13 @@ viapply <- function(X, FUN, ..., USE.NAMES = TRUE) {
 }
 
 vcapply <- function(X, FUN, ..., USE.NAMES = TRUE) {
-  vapply(X = X, FUN = FUN, FUN.VALUE = character(1L), ..., USE.NAMES = USE.NAMES)
+  vapply(
+    X = X,
+    FUN = FUN,
+    FUN.VALUE = character(1L),
+    ...,
+    USE.NAMES = USE.NAMES
+  )
 }
 
 stopc <- function(...) {
