@@ -3,22 +3,22 @@
 #include "DbColumnDataSource.h"
 #include "integer64.h"
 
-DbColumnStorage::DbColumnStorage(DATA_TYPE dt_, const R_xlen_t capacity_, const int n_max_,
-                                 const DbColumnDataSource& source_)
-  :
-  i(0),
-  dt(dt_),
-  n_max(n_max_),
-  source(source_)
-{
+DbColumnStorage::DbColumnStorage(
+  DATA_TYPE dt_,
+  const R_xlen_t capacity_,
+  const int n_max_,
+  const DbColumnDataSource& source_
+)
+    : i(0), dt(dt_), n_max(n_max_), source(source_) {
   data = allocate(get_new_capacity(capacity_), dt);
 }
 
-DbColumnStorage::~DbColumnStorage() {
-}
+DbColumnStorage::~DbColumnStorage() {}
 
 DbColumnStorage* DbColumnStorage::append_col() {
-  if (source.is_null()) return append_null();
+  if (source.is_null()) {
+    return append_null();
+  }
   return append_data();
 }
 
@@ -27,7 +27,9 @@ DATA_TYPE DbColumnStorage::get_item_data_type() const {
 }
 
 DATA_TYPE DbColumnStorage::get_data_type() const {
-  if (dt == DT_UNKNOWN) return source.get_decl_data_type();
+  if (dt == DT_UNKNOWN) {
+    return source.get_decl_data_type();
+  }
   return dt;
 }
 
@@ -36,7 +38,9 @@ SEXP DbColumnStorage::allocate(const R_xlen_t length, DATA_TYPE dt) {
   auto class_ = class_from_datatype(dt);
 
   SEXP ret = PROTECT(Rf_allocVector(type, length));
-  if (!Rf_isNull(class_)) Rf_setAttrib(ret, R_ClassSymbol, class_);
+  if (!Rf_isNull(class_)) {
+    Rf_setAttrib(ret, R_ClassSymbol, class_);
+  }
   ret = set_attribs_from_datatype(ret, dt);
   UNPROTECT(1);
   return ret;
@@ -61,18 +65,21 @@ R_xlen_t DbColumnStorage::get_capacity() const {
   return Rf_xlength(data);
 }
 
-R_xlen_t DbColumnStorage::get_new_capacity(const R_xlen_t desired_capacity) const {
+R_xlen_t DbColumnStorage::get_new_capacity(
+  const R_xlen_t desired_capacity
+) const {
   if (n_max < 0) {
     const R_xlen_t MIN_DATA_CAPACITY = 100;
     return std::max(desired_capacity, MIN_DATA_CAPACITY);
-  }
-  else {
+  } else {
     return std::max(desired_capacity, R_xlen_t(1));
   }
 }
 
 DbColumnStorage* DbColumnStorage::append_null() {
-  if (i < get_capacity()) fill_default_value();
+  if (i < get_capacity()) {
+    fill_default_value();
+  }
   ++i;
   return this;
 }
@@ -82,11 +89,19 @@ void DbColumnStorage::fill_default_value() {
 }
 
 DbColumnStorage* DbColumnStorage::append_data() {
-  if (dt == DT_UNKNOWN) return append_data_to_new(dt);
-  if (i >= get_capacity()) return append_data_to_new(dt);
+  if (dt == DT_UNKNOWN) {
+    return append_data_to_new(dt);
+  }
+  if (i >= get_capacity()) {
+    return append_data_to_new(dt);
+  }
   DATA_TYPE new_dt = source.get_data_type();
-  if (dt == DT_INT && new_dt == DT_INT64) return append_data_to_new(DT_INT64);
-  if (dt == DT_INT && new_dt == DT_REAL) return append_data_to_new(DT_REAL);
+  if (dt == DT_INT && new_dt == DT_INT64) {
+    return append_data_to_new(DT_INT64);
+  }
+  if (dt == DT_INT && new_dt == DT_REAL) {
+    return append_data_to_new(DT_REAL);
+  }
 
   fetch_value();
   ++i;
@@ -94,11 +109,14 @@ DbColumnStorage* DbColumnStorage::append_data() {
 }
 
 DbColumnStorage* DbColumnStorage::append_data_to_new(DATA_TYPE new_dt) {
-  if (new_dt == DT_UNKNOWN) new_dt = source.get_data_type();
+  if (new_dt == DT_UNKNOWN) {
+    new_dt = source.get_data_type();
+  }
 
   R_xlen_t desired_capacity = (n_max < 0) ? (get_capacity() * 2) : (n_max - i);
 
-  DbColumnStorage* spillover = new DbColumnStorage(new_dt, desired_capacity, n_max, source);
+  DbColumnStorage* spillover =
+    new DbColumnStorage(new_dt, desired_capacity, n_max, source);
   return spillover->append_data();
 }
 
@@ -190,7 +208,7 @@ cpp11::sexp DbColumnStorage::class_from_datatype(DATA_TYPE dt) {
 
   case DT_DATETIME:
   case DT_DATETIMETZ:
-    return cpp11::as_sexp({"POSIXct", "POSIXt"});
+    return cpp11::as_sexp({ "POSIXct", "POSIXt" });
 
   default:
     return R_NilValue;
@@ -205,7 +223,8 @@ SEXP DbColumnStorage::set_attribs_from_datatype(SEXP x, DATA_TYPE dt) {
   case DT_TIME:
     return new_hms(x);
 
-  case DT_DATETIME: {
+  case DT_DATETIME:
+    {
       cpp11::sexp ro = x;
       ro.attr("tzone") = "UTC";
       return ro;
@@ -260,11 +279,15 @@ void DbColumnStorage::fill_default_value(SEXP data, DATA_TYPE dt, R_xlen_t i) {
   }
 }
 
-void DbColumnStorage::copy_value(SEXP x, DATA_TYPE dt, const int tgt, const int src) const {
+void DbColumnStorage::copy_value(
+  SEXP x,
+  DATA_TYPE dt,
+  const int tgt,
+  const int src
+) const {
   if (Rf_isNull(data)) {
     fill_default_value(x, dt, tgt);
-  }
-  else {
+  } else {
     switch (dt) {
     case DT_BOOL:
       LOGICAL(x)[tgt] = LOGICAL(data)[src];
@@ -279,8 +302,7 @@ void DbColumnStorage::copy_value(SEXP x, DATA_TYPE dt, const int tgt, const int
       case INTSXP:
         if (INTEGER(data)[src] == NA_INTEGER) {
           INTEGER64(x)[tgt] = NA_INTEGER64;
-        }
-        else {
+        } else {
           INTEGER64(x)[tgt] = INTEGER(data)[src];
         }
         break;
@@ -288,8 +310,7 @@ void DbColumnStorage::copy_value(SEXP x, DATA_TYPE dt, const int tgt, const int
       case REALSXP:
         if (R_IsNA(INTEGER64(data)[src])) {
           INTEGER64(x)[tgt] = NA_INTEGER64;
-        }
-        else {
+        } else {
           INTEGER64(x)[tgt] = INTEGER64(data)[src];
         }
         break;
@@ -301,8 +322,7 @@ void DbColumnStorage::copy_value(SEXP x, DATA_TYPE dt, const int tgt, const int
       case INTSXP:
         if (INTEGER(data)[src] == NA_INTEGER) {
           REAL(x)[tgt] = NA_REAL;
-        }
-        else {
+        } else {
           REAL(x)[tgt] = INTEGER(data)[src];
         }
         break;
