@@ -5,6 +5,8 @@
 
 #ifdef _WIN32
 #include <winsock2.h>
+#else
+#include <sys/select.h>
 #endif
 
 DbConnection::DbConnection(
