@@ -27,7 +27,10 @@ test_that("check_interrupts = TRUE interrupts immediately (#336)", {
   session$run(function() {
     library(RPostgres)
     .GlobalEnv$conn <- postgresDefault(check_interrupts = TRUE)
-    .GlobalEnv$connPid <- dbGetQuery(.GlobalEnv$conn, "SELECT pg_backend_pid() AS pid")$pid
+    .GlobalEnv$connPid <- dbGetQuery(
+      .GlobalEnv$conn,
+      "SELECT pg_backend_pid() AS pid"
+    )$pid
     .GlobalEnv$checkConn <- postgresDefault()
     invisible()
   })
@@ -43,10 +46,13 @@ test_that("check_interrupts = TRUE interrupts immediately (#336)", {
   session$read()
 
   queryStatus = session$run(function() {
-    dbGetQuery(.GlobalEnv$checkConn, "SELECT state FROM pg_stat_activity WHERE pid = $1", params = .GlobalEnv$connPid)
+    dbGetQuery(
+      .GlobalEnv$checkConn,
+      "SELECT state FROM pg_stat_activity WHERE pid = $1",
+      params = .GlobalEnv$connPid
+    )
   })
   expect_equal(queryStatus$state, "idle")
 
-
   session$close()
 })
