@@ -1,5 +1,4 @@
 if (postgresHasDefault()) {
-
   with_database_connection({
     describe("Writing to the database", {
       test_that("writing to a database table is successful", {
@@ -45,10 +44,22 @@ if (postgresHasDefault()) {
             Petal.Width = as.integer(Petal.Width),
             Species = as.character(Species)
           )
-          field.types <- c("real", "double precision", "numeric", "bigint", "text")
+          field.types <- c(
+            "real",
+            "double precision",
+            "numeric",
+            "bigint",
+            "text"
+          )
           names(field.types) <- names(iris2)
 
-          dbWriteTable(con, "iris", iris2, field.types = field.types, temporary = TRUE)
+          dbWriteTable(
+            con,
+            "iris",
+            iris2,
+            field.types = field.types,
+            temporary = TRUE
+          )
 
           iris3 <- transform(
             iris2,
@@ -57,12 +68,19 @@ if (postgresHasDefault()) {
           expect_equal(dbReadTable(con, "iris"), iris3)
 
           # http://stackoverflow.com/questions/2146705/select-datatype-of-the-field-in-postgres
-          types <- DBI::dbGetQuery(con,
-            paste("select column_name, data_type from information_schema.columns ",
-              "where table_name = 'iris'"))
-          expected <- data.frame(column_name = colnames(iris2),
-            data_type = field.types, stringsAsFactors = FALSE)
-          types    <- without_rownames(types[order(types$column_name), ])
+          types <- DBI::dbGetQuery(
+            con,
+            paste(
+              "select column_name, data_type from information_schema.columns ",
+              "where table_name = 'iris'"
+            )
+          )
+          expected <- data.frame(
+            column_name = colnames(iris2),
+            data_type = field.types,
+            stringsAsFactors = FALSE
+          )
+          types <- without_rownames(types[order(types$column_name), ])
           expected <- without_rownames(expected[order(expected$column_name), ])
 
           expect_equal(types, expected)
@@ -71,14 +89,36 @@ if (postgresHasDefault()) {
 
       test_that("Appending fails when using the field.types argument", {
         with_table(con, "iris", {
-          iris2       <- transform(iris, Petal.Width = as.integer(Petal.Width),
-            Species = as.character(Species))
-          field.types <- c("real", "double precision", "numeric", "bigint", "text")
+          iris2 <- transform(
+            iris,
+            Petal.Width = as.integer(Petal.Width),
+            Species = as.character(Species)
+          )
+          field.types <- c(
+            "real",
+            "double precision",
+            "numeric",
+            "bigint",
+            "text"
+          )
           names(field.types) <- names(iris2)
 
-          dbWriteTable(con, "iris", iris2, field.types = field.types, temporary = TRUE)
+          dbWriteTable(
+            con,
+            "iris",
+            iris2,
+            field.types = field.types,
+            temporary = TRUE
+          )
           expect_error(
-            dbWriteTable(con, "iris", iris2, field.types = field.types, append = TRUE, temporary = TRUE),
+            dbWriteTable(
+              con,
+              "iris",
+              iris2,
+              field.types = field.types,
+              append = TRUE,
+              temporary = TRUE
+            ),
             "field[.]types"
           )
         })
@@ -87,7 +127,10 @@ if (postgresHasDefault()) {
 
     describe("Writing to the database with possible numeric precision issues", {
       # reference value
-      value <- data.frame(x = -0.000064925595060641, y = -0.00006492559506064059)
+      value <- data.frame(
+        x = -0.000064925595060641,
+        y = -0.00006492559506064059
+      )
       test_that("dbWriteTable(copy = F)", {
         with_table(con, "xy", {
           dbWriteTable(con, name = "xy", value = value, copy = F)
@@ -97,7 +140,10 @@ if (postgresHasDefault()) {
 
       test_that("dbWriteTable(append = T, copy = F)", {
         with_table(con, "xy", {
-          dbExecute(con, "CREATE TEMPORARY TABLE xy ( x numeric NOT NULL, y numeric NOT NULL);")
+          dbExecute(
+            con,
+            "CREATE TEMPORARY TABLE xy ( x numeric NOT NULL, y numeric NOT NULL);"
+          )
           dbWriteTable(con, name = "xy", value = value, append = T, copy = F)
           expect_equal(dbGetQuery(con, "SELECT * FROM xy"), value)
         })
@@ -105,7 +151,10 @@ if (postgresHasDefault()) {
 
       test_that("dbWriteTable(append = T, copy = T)", {
         with_table(con, "xy", {
-          dbExecute(con, "CREATE TEMPORARY TABLE xy ( x numeric NOT NULL, y numeric NOT NULL);")
+          dbExecute(
+            con,
+            "CREATE TEMPORARY TABLE xy ( x numeric NOT NULL, y numeric NOT NULL);"
+          )
           dbWriteTable(con, name = "xy", value = value, append = T, copy = T)
           expect_equal(dbGetQuery(con, "SELECT * FROM xy"), value)
         })
@@ -113,7 +162,15 @@ if (postgresHasDefault()) {
 
       test_that("dbWriteTable(append = F, copy = T, field.types=NUMERIC)", {
         with_table(con, "xy", {
-          dbWriteTable(con, name = "xy", value = value, overwrite = F, append = F, copy = T, field.types = c(x = "NUMERIC", y = "NUMERIC"))
+          dbWriteTable(
+            con,
+            name = "xy",
+            value = value,
+            overwrite = F,
+            append = F,
+            copy = T,
+            field.types = c(x = "NUMERIC", y = "NUMERIC")
+          )
           expect_equal(dbGetQuery(con, "SELECT * FROM xy"), value)
         })
       })
@@ -123,7 +180,10 @@ if (postgresHasDefault()) {
       test_that("Inf values come back correctly", {
         skip_on_cran()
 
-        res <- dbGetQuery(con, "SELECT '-inf'::float8 AS a, '+inf'::float8 AS b, 'NaN'::float8 AS c, NULL::float8 AS d")
+        res <- dbGetQuery(
+          con,
+          "SELECT '-inf'::float8 AS a, '+inf'::float8 AS b, 'NaN'::float8 AS c, NULL::float8 AS d"
+        )
         expect_equal(res$a, -Inf)
         expect_equal(res$b, Inf)
         expect_true(is.nan(res$c))
@@ -136,7 +196,8 @@ if (postgresHasDefault()) {
 
         with_table(con, "xy", {
           data <- data.frame(
-            column_1 = c("A", "B", "C"), column_2 = c(1, Inf, 3),
+            column_1 = c("A", "B", "C"),
+            column_2 = c(1, Inf, 3),
             stringsAsFactors = FALSE
           )
           dbWriteTable(con, "xy", data, row.names = FALSE)
@@ -147,7 +208,6 @@ if (postgresHasDefault()) {
       })
     })
 
-
     describe("Name clashes", {
       test_that("Can write to temporary table if permanent table exists (#402)", {
         skip_on_cran()
@@ -155,7 +215,13 @@ if (postgresHasDefault()) {
         dbWriteTable(con, "my_name_clash", data.frame(a = 1), overwrite = TRUE)
         expect_equal(dbReadTable(con, "my_name_clash"), data.frame(a = 1))
 
-        dbWriteTable(con, "my_name_clash", data.frame(b = 2), overwrite = TRUE, temporary = TRUE)
+        dbWriteTable(
+          con,
+          "my_name_clash",
+          data.frame(b = 2),
+          overwrite = TRUE,
+          temporary = TRUE
+        )
         expect_equal(dbReadTable(con, "my_name_clash"), data.frame(b = 2))
 
         dbRemoveTable(con, "my_name_clash", temporary = TRUE)
@@ -166,5 +232,4 @@ if (postgresHasDefault()) {
       })
     })
   })
-
 }
