@@ -84,7 +84,10 @@ test_that("timestamp without time zone is returned correctly (#221)", {
   con <- postgresDefault()
   on.exit(dbDisconnect(con))
 
-  out <- dbGetQuery(con, "SELECT CAST('1960-01-01 12:00:00' AS timestamp) AS before_epoch")
+  out <- dbGetQuery(
+    con,
+    "SELECT CAST('1960-01-01 12:00:00' AS timestamp) AS before_epoch"
+  )
   expect_equal(as.Date(out[[1]]), as.Date("1960-01-01"))
 })
 
@@ -100,8 +103,12 @@ test_that("timezone is passed on to the connection (#229)", {
     lubridate::hours(example$val)
 
   dbWriteTable(
-    con, "example", example, temporary = TRUE,
-    overwrite = TRUE, append = FALSE
+    con,
+    "example",
+    example,
+    temporary = TRUE,
+    overwrite = TRUE,
+    append = FALSE
   )
   res <- dbReadTable(con, "example")
   expect_equal(res, example)
